numina.drps — Loading DRPS — Numina 0.20.dev0 documentation

# `numina.drps` — Loading DRPS

DRP system wide initialization

`numina.drps.` `get_system_drps`()

  Load all compatible DRPs in the system

DRP storage class

class `numina.drps.drpbase.` `DrpBase`

  Store DRPs, base class

class `numina.drps.drpbase.` `DrpGeneric`(drps=None)

  Store DRPs.in a dictionary

  `query_all`()

    Return all available DRPs in internal storage

  `query_by_name`(name)

    Query DRPs in internal storage by name

DRP system-wide loader

class `numina.drps.drpsystem.` `DrpSystem`(entry_point='numina.pipeline.1')

  Load DRPs from the system.

  classmethod `iload`(entry_point='numina.pipeline.1')

    Load all available DRPs in ‘entry_point’.

  `load`()

    Load all available DRPs in ‘entry_point’.

  classmethod `load_drp`(name, entry_point='numina.pipeline.1')

    Load all available DRPs in ‘entry_point’.